"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const server_settings_1 = require("../../server-settings");
exports.default = (version, authenticatedUser, isAdmin) => {
    const result = {
        _links: {
            'self': { href: '/', title: 'Auth API Home' },
            'authenticated-as': { href: '/user/' + authenticatedUser.id, title: authenticatedUser.nickname },
            'authorize': { href: '/authorize', title: 'OAuth2 authorize endpoint', type: 'text/html' },
            'change-password': { href: '/changepassword', title: 'Change user\'s password' },
            'introspect': {
                href: '/introspect',
                title: 'OAuth2 Token Introspection',
                hints: {
                    allow: ['POST'],
                }
            },
            'logout': {
                href: '/logout',
                title: 'Log out',
            },
            'token': {
                href: '/token',
                title: 'OAuth2 protocol endpoint',
                hints: {
                    allow: ['POST'],
                }
            },
            'privilege-collection': {
                href: '/privilege',
                title: 'List of available privileges',
            },
            'user-collection': { href: '/user', title: 'List of users' },
            'oauth_server_metadata_uri': {
                href: '/.well-known/oauth-authorization-server',
                title: 'OAuth 2.0 Authorization Server Metadata'
            }
        },
        version: version,
    };
    if (server_settings_1.getSetting('registration.enabled')) {
        result._links.registration = {
            href: '/register',
            title: 'Create a new user account',
            type: 'text/html'
        };
    }
    if (isAdmin) {
        result._links['exchange-one-time-token'] = {
            href: '/exchange-one-time-token',
            title: 'Exchange a one-time token for a Access and Refresh token',
        };
    }
    return result;
};
//# sourceMappingURL=hal.js.map