"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const controller_1 = __importDefault(require("@curveball/controller"));
const http_errors_1 = require("@curveball/http-errors");
const querystring_1 = __importDefault(require("querystring"));
const service_1 = __importDefault(require("../log/service"));
const types_1 = require("../log/types");
const server_settings_1 = require("../server-settings");
const userService = __importStar(require("../user/service"));
const html_1 = require("./formats/html");
class LoginController extends controller_1.default {
    async get(ctx) {
        ctx.response.type = 'text/html';
        ctx.response.body = html_1.loginForm(ctx.query.msg, ctx.query.error, await server_settings_1.getSetting('registration.enabled'), await server_settings_1.getSetting('totp'));
    }
    async post(ctx) {
        let user;
        try {
            user = await userService.findByIdentity('mailto:' + ctx.request.body.userName);
        }
        catch (err) {
            if (err instanceof http_errors_1.NotFound) {
                service_1.default(types_1.EventType.loginFailed, ctx);
                return this.redirectToLogin(ctx, '', 'Incorrect username or password');
            }
            else {
                throw err;
            }
        }
        if (!await userService.validatePassword(user, ctx.request.body.password)) {
            service_1.default(types_1.EventType.loginFailed, ctx.ip(), user.id);
            return this.redirectToLogin(ctx, '', 'Incorrect username or password');
        }
        if (!user.active) {
            service_1.default(types_1.EventType.loginFailedInactive, ctx.ip(), user.id, ctx.request.headers.get('User-Agent'));
            return this.redirectToLogin(ctx, '', 'This account is inactive. Please contact Admin');
        }
        if (ctx.request.body.totp) {
            if (!await userService.validateTotp(user, ctx.request.body.totp)) {
                service_1.default(types_1.EventType.totpFailed, ctx.ip(), user.id);
                return this.redirectToLogin(ctx, '', 'Incorrect TOTP code');
            }
        }
        else if (await userService.hasTotp(user)) {
            return this.redirectToLogin(ctx, '', 'TOTP token required');
        }
        else if (await server_settings_1.getSetting('totp') === 'required') {
            return this.redirectToLogin(ctx, '', 'The system administrator has made TOTP tokens mandatory, but this user did not have a TOTP configured. Login is disabled');
        }
        ctx.state.session = {
            user: user,
        };
        service_1.default(types_1.EventType.loginSuccess, ctx);
        ctx.status = 303;
        ctx.response.headers.set('Location', '/');
    }
    async redirectToLogin(ctx, msg, error) {
        ctx.response.status = 303;
        ctx.response.headers.set('Location', '/login?' + querystring_1.default.stringify({ msg, error }));
    }
}
exports.default = new LoginController();
//# sourceMappingURL=controller.js.map