"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const controller_1 = __importDefault(require("@curveball/controller"));
const http_errors_1 = require("@curveball/http-errors");
const privilegeService = __importStar(require("../../privilege/service"));
const userHal = __importStar(require("../../user/formats/hal"));
const oauth2Service = __importStar(require("../service"));
/**
 * The /validate-bearer endpoint can check if a bearer token
 * is valid and return some information about it.
 *
 * It is superseded by the standard /introspect endpoint
 * and should no longer be used
 */
class ValidateBearerController extends controller_1.default {
    async post(ctx) {
        if (ctx.request.type !== 'application/json') {
            throw new http_errors_1.BadRequest('Request must have an application/json Content-Type');
        }
        const bearer = ctx.request.body.bearer;
        if (!bearer) {
            throw new http_errors_1.BadRequest('The "bearer" property must be provided');
        }
        let token;
        try {
            token = await oauth2Service.getTokenByAccessToken(bearer);
        }
        catch (err) {
            if (err instanceof http_errors_1.NotFound) {
                throw new http_errors_1.BadRequest('Unknown access token');
            }
            else {
                throw err;
            }
        }
        const privileges = await privilegeService.getPrivilegesForUser(token.user);
        ctx.response.body = userHal.item(token.user, privileges);
    }
}
exports.default = new ValidateBearerController();
//# sourceMappingURL=validate-bearer.js.map